"""Configuration module for Aetheris."""

from .exclusion_patterns import (
    DEEP_CLEAN_EXCLUSIONS,
    DEFAULT_EXCLUSIONS,
    DEV_TOOLING_EXCLUSIONS,
    OS_ARTIFACT_EXCLUSIONS,
    SECURITY_EXCLUSIONS,
    TEST_EXCLUSIONS,
)
from .secret_patterns import (
    HIGH_CONFIDENCE_PATTERNS,
    MEDIUM_CONFIDENCE_PATTERNS,
    PROVIDER_PATTERNS,
    SECRET_PATTERNS,
)

__all__ = [
    "DEFAULT_EXCLUSIONS",
    "SECURITY_EXCLUSIONS",
    "OS_ARTIFACT_EXCLUSIONS",
    "DEV_TOOLING_EXCLUSIONS",
    "TEST_EXCLUSIONS",
    "DEEP_CLEAN_EXCLUSIONS",
    "SECRET_PATTERNS",
    "HIGH_CONFIDENCE_PATTERNS",
    "MEDIUM_CONFIDENCE_PATTERNS",
    "PROVIDER_PATTERNS",
]
